summaryrefslogtreecommitdiffstats
path: root/sca-java-2.x/trunk/modules/core-spi/src/main
diff options
context:
space:
mode:
authorslaws <slaws@13f79535-47bb-0310-9956-ffa450edef68>2010-12-07 22:05:44 +0000
committerslaws <slaws@13f79535-47bb-0310-9956-ffa450edef68>2010-12-07 22:05:44 +0000
commit1c92473c0cfa75339884087de096c0feed1378c5 (patch)
tree3f3657373b76bea34ca6ae0ec585a44cdaac236d /sca-java-2.x/trunk/modules/core-spi/src/main
parentbf9d7e7e70b201ed21ef9e0732b335b5dbce928f (diff)
TUSCANY-3801 - missed files from previous check in.
git-svn-id: http://svn.us.apache.org/repos/asf/tuscany@1043211 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'sca-java-2.x/trunk/modules/core-spi/src/main')
-rw-r--r--sca-java-2.x/trunk/modules/core-spi/src/main/java/org/apache/tuscany/sca/invocation/InterceptorAsync.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/sca-java-2.x/trunk/modules/core-spi/src/main/java/org/apache/tuscany/sca/invocation/InterceptorAsync.java b/sca-java-2.x/trunk/modules/core-spi/src/main/java/org/apache/tuscany/sca/invocation/InterceptorAsync.java
index 3819147526..50bcf13b04 100644
--- a/sca-java-2.x/trunk/modules/core-spi/src/main/java/org/apache/tuscany/sca/invocation/InterceptorAsync.java
+++ b/sca-java-2.x/trunk/modules/core-spi/src/main/java/org/apache/tuscany/sca/invocation/InterceptorAsync.java
@@ -20,21 +20,21 @@ package org.apache.tuscany.sca.invocation;
/**
* Allows asynchronous wires to be navigated in reverse in order for the
* reponse to be processed.
*
*/
-public interface InterceptorAsync extends Interceptor, InvokerAsync {
+public interface InterceptorAsync extends Interceptor, InvokerAsyncRequest, InvokerAsyncResponse {
/**
* Sets the previous invoker
* @param next The previous invoker
*/
- void setPrevious(InvokerAsync previous);
+ void setPrevious(InvokerAsyncResponse previous);
/**
* Returns the previous invoker or null
* @return The previous Invoker
*/
- InvokerAsync getPrevious();
-
+ InvokerAsyncResponse getPrevious();
+
}
@@ -20,21 +20,21 @@ package org.apache.tuscany.sca.invocation;
/**
* Allows asynchronous wires to be navigated in reverse in order for the
- * reponse to be processed.
+ * response to be processed.
*
*/